@@ -1185,6 +1185,8 @@ addScreen (CompDisplay *display,
     s->windowGrabNotify   = windowGrabNotify;
     s->windowUngrabNotify = windowUngrabNotify;
 
+    s->windowStateChangeNotify = windowStateChangeNotify;
+
     s->getProcAddress = 0;
 
     if (!XGetWindowAttributes (dpy, s->root, &s->attrib))
@@ -1364,7 +1366,7 @@ addScreen (CompDisplay *display,
 	    GLint maxTextureSize;
 
 	    glGetIntegerv (GL_MAX_RECTANGLE_TEXTURE_SIZE_NV, &maxTextureSize);
-	    if (maxTextureSize < s->maxTextureSize)
+	    if (maxTextureSize > s->maxTextureSize)
 		s->maxTextureSize = maxTextureSize;
 	}
     }
